@@ -35,11 +35,14 @@ log = logging.getLogger(__name__)
 __self__ = "dvershinin/lastversion"
 
 
-def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
+def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
            short_urls=False, major=None, only=None, at=None):
     """Find latest release version for a project.
 
     Args:
+        major (str): Only consider versions which are "descendants" of this major version string
+        short_urls (bool): Whether we should try to return shorter URLs for release data
+        assets_filter (str): Regular expression for filtering assets for the latest release
         only (str): Only consider tags with this text. Useful for repos with multiple projects
         repo (str): Repository specifier in any form.
         output_format (str): Affects return format. Possible values `version`, `json`, `dict`,
@@ -57,7 +60,8 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     cache_dir = user_cache_dir("lastversion")
     log.info("Using cache directory: {}.".format(cache_dir))
     repo_data = {}
-    if repo.endswith('.yml'):
+
+    if repo.endswith('.yml') and not repo.startswith(('http://', 'https://')):
         with open(repo) as fpi:
             repo_data = yaml.safe_load(fpi)
             if 'repo' in repo_data:
@@ -69,12 +73,17 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
                 repo = repo_data['repo']
                 repo_data['name'] = name
 
-    # find the right hosting for this repo
-    if not at or '/' in repo:
+    if repo.startswith(('http://', 'https://')) and repo.endswith('Chart.yaml'):
+        at = 'helm_chart'
+
+    if (not at or '/' in repo) and at != 'helm_chart':
+        # find the right hosting for this repo
         project_holder = HolderFactory.get_instance_for_repo(repo, only=only)
     else:
         project_holder = HolderFactory.HOLDERS[at](repo, hostname=None)
 
+    project_holder.set_only(only)
+
     # we are completely "offline" for 1 hour, not even making conditional requests
     # heuristic=ExpiresAfter(hours=1)   <- make configurable
     with CacheControl(project_holder, cache=FileCache(cache_dir)) as s:
@@ -85,8 +94,8 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     if not release:
         return None
 
-    from_type = 'Located the latest release at: {}'.format(
-        project_holder.get_canonical_link()
+    from_type = 'Located the latest release tag {} at: {}'.format(
+        release['tag_name'], project_holder.get_canonical_link()
     )
     if 'type' in release:
         from_type = '{} via {} mechanism'.format(from_type, release['type'])
@@ -338,11 +347,10 @@ def main():
         print(max([args.newer_than, base_compare]))
         sys.exit(2 if base_compare <= args.newer_than else 0)
 
-    res = None
     # other action are either getting release or doing something with release (extend get action)
     try:
-            res = latest(args.repo, args.format, args.pre, args.filter,
-                         args.shorter_urls, args.major, args.only, args.at)
+        res = latest(args.repo, args.format, args.pre, args.filter,
+                     args.shorter_urls, args.major, args.only, args.at)
     except (ApiCredentialsError, BadProjectError) as error:
         sys.stderr.write(str(error) + os.linesep)
         if isinstance(error, ApiCredentialsError) and "GITHUB_API_TOKEN" not in os.environ and \
